import java.io.*;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Collections;
import java.util.Set;
import java.util.SortedMap;
import java.util.TreeMap;

public class XMLCreator {
	private File file;
	private SortedMap<String, Book> m;
	private StringBuffer sb;
	private Thread[] thread;

	public XMLCreator(File file, SortedMap<String, Book> map, StringBuffer sb){
		this.file = file;
		this.m = map;
		this.sb = sb;
		URL[] url = new URL[19];
		for(int i = 0; i < url.length; i++){
			url[i] = null;
		}
		try{
			url[0] = new URL("http://asciimw.jp/calendar/");
			url[1] = new URL("http://www.mediafactory.co.jp/comic-alive/comics.php?MODE=new");
			url[2] = new URL("http://www.comic-flapper.com/comics");
			url[3] = new URL("http://www.comic-gene.com/comics/latest");
			url[4] = new URL("http://www.enterbrain.co.jp/schedule/index.html");
			url[5] = new URL("http://www.fujimishobo.co.jp/books/index.php");
			url[6] = new URL("http://www.dokidokivisual.com/comics/");
			url[7] = new URL("http://www.futabasha.co.jp/booksdb/book/calview/");
			url[8] = new URL("http://www.kadokawa.co.jp/comic/kongetsu.html");
			url[9] = new URL("http://www.kadokawa.co.jp/lnovel/kongetsu.html");
			url[10] = new URL("http://www.bookclub.kodansha.co.jp/bc2_bc/sinkan_list_x.jsp?x=C");
			url[11] = new URL("http://www.bookclub.kodansha.co.jp/bc2_bc/sinkan_list_x.jsp?x=S");
			url[12] = new URL("http://www.mag-garden.co.jp/view.php?mode=new#");
			url[13] = new URL("http://www.mediafactory.co.jp/bunkoj/release/index");
			url[14] = new URL("http://www.square-enix.com/jp/magazine/top/release/");
			url[15] = new URL("http://skygarden.shogakukan.co.jp/skygarden/owa/solc_new?mm=0&type=c&seq=0&page=");
			url[16] = new URL("http://www.s-manga.net/newcomic/");
			url[17] = new URL("http://books.shueisha.co.jp/CGI/search/sale_yotei.cgi?mode=to&jyanru=bun&series=%a5%b9%a1%bc%a5%d1%a1%bc%a5%c0%a5%c3%a5%b7%a5%e5%ca%b8%b8%cb");
			url[18] = new URL("http://data.ichijinsha.co.jp/book/newbooks/newbooks_list.php");
		}catch(MalformedURLException murle){
			sb.append(murle + "・");
			return;
		}

		thread = new Thread[19];
		thread[0] = new Thread(new AMWInfogetter(url[0], m, sb));
		thread[1] = new Thread(new COMAInfogetter(url[1], m, sb));
		thread[2] = new Thread(new COMFInfogetter(url[2], m, sb));
		thread[3] = new Thread(new COMGInfogetter(url[3], m, sb));
		thread[4] = new Thread(new EBInfogetter(url[4], m, sb));
		thread[5] = new Thread(new FujimiInfogetter(url[5], m, sb));
		thread[6] = new Thread(new HOUBCInfogetter(url[6], m, sb));
		thread[7] = new Thread(new HUTInfogetter(url[7], m, sb));
		thread[8] = new Thread(new KADCInfogetter(url[8], m, sb));
		thread[9] = new Thread(new KADInfogetter(url[9], m, sb));
		thread[10] = new Thread(new KDNCInfogetter(url[10], m, sb));
		thread[11] = new Thread(new KDNLInfogetter(url[11], m, sb));
		thread[12] = new Thread(new MAGInfogetter(url[12], m, sb));
		thread[13] = new Thread(new MFBInfogetter(url[13], m, sb));
		thread[14] = new Thread(new SEnixInfogetter(url[14], m, sb));
		thread[15] = new Thread(new SYOGKCInfogetter(url[15], m, sb));
		thread[16] = new Thread(new SyueiCInfogetter(url[16], m, sb));
		thread[17] = new Thread(new SyueiSInfogetter(url[17], m, sb));
		thread[18] = new Thread(new ItijinInfogetter(url[18], m, sb));
	}
	public void createXML(){
		try{
			for(int i = 0; i < thread.length; i++){
				thread[i].start();
			}
			try{
				for(int i = 0; i < thread.length; i++){
					thread[i].join();
				}
			}catch(InterruptedException interE){
				sb.append(interE + "・");
				return;
			}

			PrintWriter writer =
				new PrintWriter(
					new BufferedWriter(
							new OutputStreamWriter(
									new FileOutputStream(file), "utf-8")));

			writer.println("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>");
			writer.println("<!DOCTYPE Books[");
			writer.println("<!ELEMENT Books (Book+)>");
			writer.println("<!ELEMENT Book (title, author, publisher, label, date, price)>");
			writer.println("<!ELEMENT title (#PCDATA)>");
			writer.println("<!ELEMENT author (#PCDATA)>");
			writer.println("<!ELEMENT publisher (#PCDATA)>");
			writer.println("<!ELEMENT label (#PCDATA)>");
			writer.println("<!ELEMENT date (#PCDATA)>");
			writer.println("<!ELEMENT price (#PCDATA)>");
			writer.println("]>");
			writer.println("<Books>");
			Set<String> set = m.keySet();
			for(String temp : set){
				Book book = m.get(temp);
				writer.println("\t<Book>");
				writer.println("\t\t<title><![CDATA["+ book.getTitle() +"]]></title>");
				writer.println("\t\t<author><![CDATA["+ book.getAuthor() +"]]></author>");
				writer.println("\t\t<publisher><![CDATA["+ book.getPublisher() +"]]></publisher>");
				writer.println("\t\t<label><![CDATA["+ book.getLabel()+"]]></label>");
				writer.println("\t\t<date><![CDATA["+ book.getDate() +"]]></date>");
				writer.println("\t\t<price><![CDATA["+ book.getPrice() +"]]></price>");
				writer.println("\t</Book>");
			}
			writer.print("</Books>");
			writer.close();
		}catch(IOException ioe){
			sb.append(ioe + "・");
			return;
		}
	}
}
